# SPDX-License-Identifier: CC0-1.0

let
  tests = call:
    {
      log = call ./log.nix { };
      signal = call ./signal.nix { };
    } // call ./solo5 { };

in { self, apps, system, localSystem, crossSystem, genodepkgs, nixpkgs
, genode-depot, lib }:

let
  hostPkgs = import nixpkgs { system = localSystem; };
  depot = genode-depot.packages.${system};
  testPkgs = genodepkgs;

  linux = tests (import ./driver-linux.nix {
    inherit apps testPkgs hostPkgs lib depot;
  }).callTest;

  nova = (call:
    ((tests call) // {
      noux = call ./noux.nix { };
      pci = call ./pci.nix { };
      rtc = call ./rtc.nix { };
    })) (import ./driver-nova.nix {
      inherit apps system testPkgs hostPkgs lib depot;
    }).callTest;

  hw = (call:
    ((tests call) // {
      pci = call ./pci.nix { };
      rtc = call ./rtc.nix { };
    })) (import ./driver-hw.nix {
      inherit apps system testPkgs hostPkgs lib depot;
    }).callTest;

  testsToList = tests:
    map (test: {
      inherit (test) name;
      value = test;
    }) (builtins.attrValues tests);

  nova-sotest = map ({ name, value }: {
    name = name + "-sotest";
    value = value.sotest;
  }) (testsToList nova);

in with builtins;
listToAttrs ((concatLists (map (testsToList) [ linux nova hw ])) ++ nova-sotest)
